#!/usr/bin/env python3

from distutils.core import setup

setup(
    name='trydiffoscope',
    version='67.0.6',
    author="Chris Lamb",
    author_email="lamby@debian.org",
    scripts=('trydiffoscope',),
)
